mailr3440 - /1.3/prompt/molecule.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on November 04, 2007 - 19:36:
Author: bugman
Date: Sun Nov  4 19:36:00 2007
New Revision: 3440

URL: http://svn.gna.org/viewcvs/relax?rev=3440&view=rev
Log:
Implemented the molecule.display() user function.


Modified:
    1.3/prompt/molecule.py

Modified: 1.3/prompt/molecule.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/prompt/molecule.py?rev=3440&r1=3439&r2=3440&view=diff
==============================================================================
--- 1.3/prompt/molecule.py (original)
+++ 1.3/prompt/molecule.py Sun Nov  4 19:36:00 2007
@@ -179,24 +179,24 @@
         molecule.delete(mol_id=mol_id)
 
 
-    def display(self, run=None):
-        """Function for displaying the sequence.
-
-        Keyword Arguments
-        ~~~~~~~~~~~~~~~~~
-
-        run:  The name of the run.
-        """
-
-        # Function intro text.
-        if self.__relax__.interpreter.intro:
-            text = sys.ps3 + "sequence.display("
-            text = text + "run=" + `run` + ")"
-            print text
-
-        # The run argument.
-        if type(run) != str:
-            raise RelaxStrError, ('run', run)
-
-        # Execute the functional code.
-        self.__relax__.generic.sequence.display(run=run)
+    def display(self, mol_id=None):
+        """Function for displaying the molecule information.
+
+        Keyword Arguments
+        ~~~~~~~~~~~~~~~~~
+
+        mol_id:  The molecule identifier string.
+        """
+
+        # Function intro text.
+        if self.__relax__.interpreter.intro:
+            text = sys.ps3 + "molecule.display("
+            text = text + "mol_id=" + `mol_id` + ")"
+            print text
+
+        # The molecule identifier argument.
+        if type(mol_id) != str:
+            raise RelaxStrError, ('molecule identifier', mol_id)
+
+        # Execute the functional code.
+        molecule.display(mol_id=mol_id)




Related Messages


Powered by MHonArc, Updated Sun Nov 04 19:40:23 2007